instrumenttools.transpose_notes_and_chords_in_expr_from_fingered_pitch_to_sounding_pitch
========================================================================================

.. autofunction:: abjad.tools.instrumenttools.transpose_notes_and_chords_in_expr_from_fingered_pitch_to_sounding_pitch.transpose_notes_and_chords_in_expr_from_fingered_pitch_to_sounding_pitch
